From ca3a76d92277b8e5369b8f99c1ff0051f9d5ee70 Mon Sep 17 00:00:00 2001
From: Jingtang Zhang <mrdrivingduck@gmail.com>
Date: Fri, 8 Jul 2022 22:58:10 +0800
Subject: [PATCH] Fix two tabs are regarded as auto completion in test case

In this test case, when I paste the CREATE TABLE into psql,
two tabs between `name` and `text`, which are originally used for
seperation, are regarded as auto completion instruction by psql,
causing syntax error because there is no more seperation between
column name and type. Would it be better to use space here, although
the tabs are not breaking the regression?
---
 src/test/regress/expected/insert_conflict.out | 10 +++++-----
 src/test/regress/sql/insert_conflict.sql      | 10 +++++-----
 2 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/src/test/regress/expected/insert_conflict.out b/src/test/regress/expected/insert_conflict.out
index 66d8633e3e..fe32c4947d 100644
--- a/src/test/regress/expected/insert_conflict.out
+++ b/src/test/regress/expected/insert_conflict.out
@@ -497,12 +497,12 @@ drop table insertconflict;
 -- *                                                                *
 -- ******************************************************************
 create table cities (
-	name		text,
-	population	float8,
-	altitude	int		-- (in ft)
+  name    text,
+  population  float8,
+  altitude  int   -- (in ft)
 );
 create table capitals (
-	state		char(2)
+  state   char(2)
 ) inherits (cities);
 -- Create unique indexes.  Due to a general limitation of inheritance,
 -- uniqueness is only enforced per-relation.  Unique index inference
@@ -847,7 +847,7 @@ declare
     r record;
 begin
  for r in select * from inserted loop
-	raise notice 'a = %, b = %, c = %', r.a, r.b, r.c;
+  raise notice 'a = %, b = %, c = %', r.a, r.b, r.c;
  end loop;
  return new;
 end;
diff --git a/src/test/regress/sql/insert_conflict.sql b/src/test/regress/sql/insert_conflict.sql
index 23d5778b82..bfd3554927 100644
--- a/src/test/regress/sql/insert_conflict.sql
+++ b/src/test/regress/sql/insert_conflict.sql
@@ -307,13 +307,13 @@ drop table insertconflict;
 -- *                                                                *
 -- ******************************************************************
 create table cities (
-	name		text,
-	population	float8,
-	altitude	int		-- (in ft)
+  name    text,
+  population  float8,
+  altitude  int   -- (in ft)
 );
 
 create table capitals (
-	state		char(2)
+  state   char(2)
 ) inherits (cities);
 
 -- Create unique indexes.  Due to a general limitation of inheritance,
@@ -559,7 +559,7 @@ declare
     r record;
 begin
  for r in select * from inserted loop
-	raise notice 'a = %, b = %, c = %', r.a, r.b, r.c;
+  raise notice 'a = %, b = %, c = %', r.a, r.b, r.c;
  end loop;
  return new;
 end;
-- 
2.34.1

